#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # Geopandas
# 
# [geopandas](https://geopandas.org/en/stable/) est devenu le point d'entrée à tout traitement lié aux coordonnées géographiques.

# In[1]:


from jyquickhelper import add_notebook_menu
add_notebook_menu()


# ## Coordonnées géographiques, et geocoding

# In[2]:


import geopandas
import pandas


# In[3]:


df = pandas.DataFrame(dict(name=["A", "B", "C", "D", "E"],
                           address=["50 rue du moulin 08000 Charleville-Mézières",
                                    "50 rue dumoulin 08000 Charleville-Mézières",
                                    "50 rue du moulin 08000 Charleville",
                                    "29 rue Ordener 75018 Paris",
                                    "Gare Lille"]))
df


# In[4]:


from geopy.geocoders import Nominatim


# In[5]:


geolocator = Nominatim(timeout=10, user_agent = "myGeolocator")
res = geolocator.geocode("50 rue du moulin 08000 Charleville-Mézières")
res


# In[6]:


res.latitude, res.longitude, res.point


# In[7]:


coordinates = df['address'].apply(geolocator.geocode)


# In[8]:


import numpy
from shapely.geometry import Point

df['position'] = [numpy.nan if c is None else 
                  Point(c.point.longitude, c.point.latitude) for c in coordinates]
df


# In[9]:


geodf = geopandas.GeoDataFrame(df)


# In[10]:


geodf


# In[11]:


geodf.dropna()


# In[12]:


gdf = geodf.set_geometry('position')
gdf


# ## Carte

# In[13]:


gdf.plot();


# In[14]:


import cartopy.crs as ccrs
import cartopy.feature as cfeature
import matplotlib.pyplot as plt


# In[15]:


fig = plt.figure(figsize=(7,7))
ax = fig.add_subplot(1, 1, 1, projection=ccrs.PlateCarree())
ax.set_extent([-5, 10, 42, 52])

ax.add_feature(cfeature.OCEAN)
ax.add_feature(cfeature.COASTLINE)
ax.add_feature(cfeature.RIVERS)
ax.add_feature(cfeature.LAKES)
ax.add_feature(cfeature.LAND)
ax.add_feature(cfeature.BORDERS, linestyle=':')
ax.plot([2.35, 2.20], [48.85, 48.71], '.')
ax.text(2.35, 48.85, "Paris")
ax.text(2.20, 48.71, "Saclay", ha="right")
ax.set_title('France');


# In[16]:





# In[17]:


fig = plt.figure(figsize=(7,7))
ax = fig.add_subplot(1, 1, 1, projection=ccrs.PlateCarree())
ax = gdf.plot(ax=ax)
ax.add_feature(cfeature.OCEAN)
ax.add_feature(cfeature.COASTLINE)
ax.add_feature(cfeature.RIVERS)
ax.add_feature(cfeature.LAKES)
ax.add_feature(cfeature.LAND)
ax.add_feature(cfeature.BORDERS, linestyle=':')
for i in range(gdf.shape[0]):
    if gdf.geometry[i] is None:
        continue
    ax.text(gdf.geometry[i].x, gdf.geometry[i].y, gdf.name[i])
ax;


# ## Régions administratives

# In[18]: